@@ -1,10 +1,20 @@
 
 open Utils
 
+let force_link_all = ref true
+
+let link_all () =
+  if !force_link_all
+  then ["-linkall"]
+  else []
+
 let usage () =
   Printf.eprintf "Usage: %s <options> <files>\n" (Filename.basename Sys.argv.(0));
   Printf.eprintf "SPECIFIC OPTIONS:\n";
   Printf.eprintf "  -package <name>\tRefer to package when compiling\n";
+  Printf.eprintf "  -no-autoload\t\tDo not load commonly used syntax extensions (deriving, lwt, js_of_ocaml, tyxml)\n";
+  Printf.eprintf "  -type-conv\t\tUse type_conv syntax extensions instead of deriving one\n";
+  Printf.eprintf "\t\t\tIt has no effect if used in conjunction with -no-autoload\n";
   if !kind <> `Client then
     Printf.eprintf "  -infer\t\tOnly infer the type of values sent by the server\n";
   Printf.eprintf "  -dir <dir>\t\tThe directory for generated files (default %S)\n"
@@ -17,6 +27,8 @@ let usage () =
     Printf.eprintf "  -jsopt <opt>\t\tAppend option <opt> to js_of_ocaml invocation\n";
   Printf.eprintf "  -ppopt <p>\t\tAppend option <opt> to preprocessor invocation\n";
   Printf.eprintf "  -predicates <p>\tAdd predicate <p> when resolving package properties\n";
+  if !kind = `Client then
+    Printf.eprintf "  -dont-force-linkall\t\tDo not add linkall option by default\n";
   create_filter !compiler ["-help"] (help_filter 2 "STANDARD OPTIONS:");
   if !kind = `Client then
     create_filter !js_of_ocaml ["-help"] (help_filter 1 "JS_OF_OCAML OPTIONS:");
@@ -263,6 +275,7 @@ let build_client () =
   check_or_create_dir (Filename.dirname exe);
   let js = name ^ ".js" in
   create_process !compiler ( ["-o"  ;  exe ]
+           @ link_all ()
 			     @ get_common_include ()
 			     @ get_client_lib ()
 			     @ !args );
@@ -271,13 +284,16 @@ let build_client () =
 				@ !jsopt
 				@ [exe] )
 
-let rec process_option () =
+let process_option () =
   let i = ref 1 in
   while !i < Array.length Sys.argv do
     match Sys.argv.(!i) with
     | "-help" | "--help" -> usage ()
     | "-no-autoload" -> autoload_predef := false; incr i
-    | "-type_conv" -> type_conv := true; incr i
+    | "-type-conv" -> type_conv := true; incr i
+    | "-dont-force-linkall"->
+      if !kind <> `Client then usage ();
+      force_link_all := false; incr i
     | "-i" -> set_mode `Interface; incr i
     | "-c" -> set_mode `Compile; incr i
     | "-a" -> set_mode `Library; incr i
@@ -361,24 +377,36 @@ let rec process_option () =
   | `Compile | `Infer | `Interface -> ()
 
 let main () =
+  let cmd = Filename.basename Sys.argv.(0) in
+  let cmd =
+    try
+      let idx = String.index cmd '.' in
+      String.sub cmd 0 idx
+    with Not_found -> cmd in
   let k =
-    match Filename.basename Sys.argv.(0) with
-      | "eliomopt" ->
-	  compiler := ocamlopt;
-	  build_dir := default_server_dir;
-	  `ServerOpt
-      | "eliomcp" ->
-	  compiler := ocamlcp;
-	  build_dir := default_server_dir;
-	  `Server
-      | "js_of_eliom" ->
-	  compiler := ocamlc;
-	  build_dir := default_client_dir;
-	  `Client
-      | "eliomc" | _ ->
-	  compiler := ocamlc;
-	  build_dir := default_server_dir;
-	  `Server in
+    match cmd with
+    | "eliomopt" ->
+	    compiler := ocamlopt;
+	    build_dir := default_server_dir;
+	    `ServerOpt
+    | "eliomcp" ->
+	    compiler := ocamlcp;
+	    build_dir := default_server_dir;
+	    `Server
+    | "js_of_eliom" ->
+	    compiler := ocamlc;
+	    build_dir := default_client_dir;
+	    `Client
+    | "eliomc" ->
+	    compiler := ocamlc;
+	    build_dir := default_server_dir;
+	    `Server
+    | s ->
+      Format.eprintf "exec name not recognize %S: fallback to ocamlc@." s;
+  	  compiler := ocamlc;
+	    build_dir := default_server_dir;
+	    `Server
+  in
   kind := k;
   process_option ()
 
